-- help.lua

local help = {}

function help.load()
	ins = {  -- information regarding user inputs to control script
		fontsize	=  15,
		locX		=  15,		-- location on canvas
		locY		=   0,
		width		= 270,  	-- size of information window (on cavvas)
		height		= 200,
		canvasX		= 310,		-- size of canvas
		canvasY		= 230,
		colortxt	= { 192, 192, 192, 255 },
		colorbg		= { 30, 30, 50, 200 },
		txt = {
			"    Looking Glass Controls",
			" Window movement:",
			"   <up><down> or <w><s>",
			"   <left><right> or  <a><d>",
			" Background:",
			"   <f><g> fades background",
			" Size:",
			"   <j><k> changes window size",
			" Magnification:",
			"   <n><m> changes magnification",
			" Help window:",
			"   <i> closes",
			" <esc> to exit script"
			}
		}
	gr.setFont( gr.newFont( ins.fontsize ) )
	cnv = gr.newCanvas(ins.canvasX,ins.canvasY)	-- create a canvas
	--canvas:setFilter("nearest", "nearest") 			--????
	gr.setCanvas( cnv )							-- draw to canvas
		gr.setColor( unpack( ins.colorbg ) )		-- help background screen
		local mode	= 'fill'
		local x, y = ins.locX, ins.locY + ins.fontsize
		local width, height, cornerRadius = ins.width, ins.height, 10
		roundedRectangle( mode, x, y, width, height, cornerRadius )
		gr.setColor( to 'red' )					-- add red border to window
		mode		= 'line'
		gr.setLineWidth(2)
		roundedRectangle( mode, x, y, width, height, cornerRadius )
		gr.setColor( unpack( ins.colortxt ) )	-- put text on screen
		for i = 1, #ins.txt do
			gr.print( ins.txt[i], ins.locX, ins.locY + ins.fontsize * i, 0, 1, 1 )
			end
		gr.setCanvas()					-- drawing to canvas complete
	end

function help.draw()
	if show.help then
		if show.help_rotation then
			gr.draw(
				canvas, 									-- image
				ins.canvasX/2, screenHeight-ins.canvasY/2,	-- screen location
				rot, size, size,					-- scale
				ins.canvasX/2,ins.canvasY/2 )				-- center of image
			else
			gr.draw(cnv, 0, screenHeight-ins.canvasY, 0, 1, 1)
			end
		end
	end

function help.update() end

function roundedRectangle(mode, x, y, width, height, cornerRadius) -- from Passion
    cornerRadius = cornerRadius or 0  -- if radius not specified, use rectangle
	if cornerRadius == 0 then
		gr.rectangle( mode, x, y, width, height )
		else
			local xround, yround = cornerRadius, cornerRadius
			local points = {}
			local precision = (xround + yround) * .3
			local tI, hP = table.insert, .5 * pi
			xround = xround > .5*width  and .5 * width  or xround
			yround = yround > .5*height and .5 * height or yround
			local X1, Y1, X2, Y2 = x + xround, y + yround, x + width - xround, y + height - yround
			for i = 0, precision do
				local a = (i / precision - 1) * hP
				tI(points, X2 + xround * cos(a))
				tI(points, Y1 + yround * sin(a))
				end
			for i = 0, precision do
				local a = (i / precision) * hP
				tI(points, X2 + xround * cos(a))
				tI(points, Y2 + yround * sin(a))
				end
			for i = 0, precision do
				local a = (i / precision + 1) * hP
				tI(points, X1 + xround * cos(a))
				tI(points, Y2 + yround * sin(a))
				end
			for i = 0, precision do
				local a = (i / precision + 2) * hP
				tI(points, X1 + xround * cos(a))
				tI(points, Y1 + yround * sin(a))
				end
			gr.polygon( mode, unpack(points) )  -- corners connected by default
		end
	end

return help
